package com.simualteSmack;

import java.io.Reader;
import java.io.Writer;
/**      
 * @date 2011-7-31  
 * @author zhanghaitao     
 * @version 1.0 
 *     
 */
public interface SmackDebugger {
	/**
	 * Called when a user has logged in to the server. The user could be an
	 * anonymous user, this means that the user would be of the form
	 * host/resource instead of the form user@host/resource.
	 * 
	 * @param user
	 *            the user@host/resource that has just logged in
	 */
	public abstract void userHasLogged(String user);

	/**
	 * Returns the special Reader that wraps the main Reader and logs data to
	 * the GUI.
	 * 
	 * @return the special Reader that wraps the main Reader and logs data to
	 *         the GUI.
	 */
	public abstract Reader getReader();

	/**
	 * Returns the special Writer that wraps the main Writer and logs data to
	 * the GUI.
	 * 
	 * @return the special Writer that wraps the main Writer and logs data to
	 *         the GUI.
	 */
	public abstract Writer getWriter();

	/**
	 * Returns a new special Reader that wraps the new connection Reader. The
	 * connection has been secured so the connection is using a new reader and
	 * writer. The debugger needs to wrap the new reader and writer to keep
	 * being notified of the connection traffic.
	 * 
	 * @return a new special Reader that wraps the new connection Reader.
	 */
	public abstract Reader newConnectionReader(Reader reader);

	/**
	 * Returns a new special Writer that wraps the new connection Writer. The
	 * connection has been secured so the connection is using a new reader and
	 * writer. The debugger needs to wrap the new reader and writer to keep
	 * being notified of the connection traffic.
	 * 
	 * @return a new special Writer that wraps the new connection Writer.
	 */
	public abstract Writer newConnectionWriter(Writer writer);

	/**
	 * Returns the thread that will listen for all incoming packets and write
	 * them to the GUI. This is what we call "interpreted" packet data, since
	 * it's the packet data as Smack sees it and not as it's coming in as raw
	 * XML.
	 * 
	 * @return the PacketListener that will listen for all incoming packets and
	 *         write them to the GUI
	 */
	public abstract PacketListener getReaderListener();

	/**
	 * Returns the thread that will listen for all outgoing packets and write
	 * them to the GUI.
	 * 
	 * @return the PacketListener that will listen for all sent packets and
	 *         write them to the GUI
	 */
	public abstract PacketListener getWriterListener();
}
