package com.simualteSmack;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.UnsupportedEncodingException;
import java.net.Socket;
import java.net.UnknownHostException;
/**      
 * @date 2011-7-31  
 * @author zhanghaitao     
 * @version 1.0 
 *     
 */
public class XMPPConnection extends Connection {

	protected Socket socket;
	private PacketReader packetReader;

	public XMPPConnection() {
		// Create the configuration for this new connection
		// super(new ConnectionConfiguration("10.10.10.174", 9991));
		super(new ConnectionConfiguration("169.254.141.109", 9991));

	}

	/**
	 * Establishes a connection to the XMPP server and performs an automatic
	 * login only if the previous connection state was logged (authenticated).
	 * It basically creates and maintains a socket connection to the server.
	 * <p>
	 * <p/>
	 * Listeners will be preserved from a previous connection if the
	 * reconnection occurs after an abrupt termination.
	 * 
	 * @throws XMPPException
	 *             if an error occurs while trying to establish the connection.
	 *             Two possible errors can occur which will be wrapped by an
	 *             XMPPException -- UnknownHostException (XMPP error code 504),
	 *             and IOException (XMPP error code 502). The error codes and
	 *             wrapped exceptions can be used to present more appropiate
	 *             error messages to end-users.
	 */
	public void connect() {
		// Stablishes the connection, readers and writers
		connectUsingConfiguration(config);
	}

	private void connectUsingConfiguration(ConnectionConfiguration config) {
		String host = config.getHost();
		int port = config.getPort();
		try {
			this.socket = new Socket(host, port);
		} catch (UnknownHostException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
		initConnection();
	}

	/**
	 * Initializes the connection by creating a packet reader and writer and
	 * opening a XMPP stream to the server.
	 * 
	 * @throws XMPPException
	 *             if establishing a connection to the server fails.
	 */
	private void initConnection() {
		// Set the reader and writer instance variables
		initReaderAndWriter();

		packetReader = new PacketReader(this);

		addPacketListener(debugger.getReaderListener(), null);
		// Start the packet reader. The startup() method will block until we
		// get an opening stream packet back from server.
		packetReader.startup();
	}

	private void initReaderAndWriter() {
		try {
			reader = new BufferedReader(new InputStreamReader(socket
					.getInputStream(), "UTF-8"));
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		initDebugger();
	}

}
